@@ -3,8 +3,9 @@ Main interface for es service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.es import (
+    from mypy_boto3_es import (
         Client,
         DescribeReservedElasticsearchInstanceOfferingsPaginator,
         DescribeReservedElasticsearchInstancesPaginator,
@@ -12,7 +13,7 @@ Usage::
         GetUpgradeHistoryPaginator,
         ListElasticsearchInstanceTypesPaginator,
         ListElasticsearchVersionsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -24,8 +25,9 @@ Usage::
     get_upgrade_history_paginator: GetUpgradeHistoryPaginator = client.get_paginator("get_upgrade_history")
     list_elasticsearch_instance_types_paginator: ListElasticsearchInstanceTypesPaginator = client.get_paginator("list_elasticsearch_instance_types")
     list_elasticsearch_versions_paginator: ListElasticsearchVersionsPaginator = client.get_paginator("list_elasticsearch_versions")
+    ```
 """
-from mypy_boto3_es.client import ElasticsearchServiceClient, ElasticsearchServiceClient as Client
+from mypy_boto3_es.client import ElasticsearchServiceClient
 from mypy_boto3_es.paginator import (
     DescribeReservedElasticsearchInstanceOfferingsPaginator,
     DescribeReservedElasticsearchInstancesPaginator,
@@ -34,6 +36,8 @@ from mypy_boto3_es.paginator import (
     ListElasticsearchVersionsPaginator,
 )
 
+Client = ElasticsearchServiceClient
+
 
 __all__ = (
     "Client",
